#!/usr/bin/perl

use strict;
use warnings;
use lib qw(
    /home/msilva/public_html/presentations/software_testing
);

use Test::More qw(no_plan);

use_ok('Validator');

#note('Verificar metodos existentes no modulo');
can_ok('Validator', 'email');

#note verificar se objectos sao instanciados correctamente
my $v = Validator->new('debug' => 0);

isa_ok($v, 'Validator');

#note('Casos validos');
is($v->email('address' => ''), 1, 'E-mail vazio mas nao obrigatorio');
is($v->email('address' => 'omeunome@omeudominio.pt'), 1, 'Endereco valido');
is($v->email('address' => 'o.meu.nome@omeudominio.pt'), 1, 'Endereco valido com pontos na mailbox');
is($v->email('address' => 'o.meu-nome@omeudominio.pt'), 1, 'Endereco valido com pontos e tracos na mailbox');
is($v->email('address' => 'o.meu-nome_1980@omeudominio.pt'), 1, 'Endereco valido com _ e algarismos');
is($v->email('address' => 'o.meu-nome_1980@sub.dominio.omeudominio.pt'), 1, 'Endereco valido com varios sub-dominios');
is($v->email('address' => 'o.meu-nome_1980@o-meu-dominio.pt'), 1, 'Endereco valido com dominio com tracos');

#note('Casos invalidos');
is($v->email('address' => '', 'mandatory' => 1), 0, 'E-mail vazio mas obrigatorio');
is($v->email('address' => 'omeunome'), 0, 'Mailbox indicada mas nao tem arroba nem dominio');
is($v->email('address' => 'omeunome@'), 0, 'Mailbox indicada, arroba presente mas sem dominio');
is($v->email('address' => '@omeudominio.pt'), 0, 'Dominio valido mas sem nome de mailbox');
is($v->email('address' => 'omeunome@omeu@dominio.pt'), 0, 'Mais que 1 arroba');
is($v->email('address' => 'omeunome.@omeudominio.pt'), 0, 'Mailbox termina com ponto');
is($v->email('address' => 'omeunome-@omeudominio.pt'), 0, 'Mailbox termina com traco');
is($v->email('address' => '.omeunome@omeudominio.pt'), 0, 'Mailbox comeca com ponto');
is($v->email('address' => '-omeunome@omeudominio.pt'), 0, 'Mailbox comeca com traco');
is($v->email('address' => 'omeu.-nome@omeudominio.pt'), 0, 'Mailbox com dois caracteres non-word seguidos');
is($v->email('address' => 'omeunome@o_meu_dominio.pt'), 0, 'Dominio com _');
is($v->email('address' => '_o.meu-nome_1980@sub.dominio.omeudominio.pt'), 0, 'Mailbox a comecar por _');
is($v->email('address' => 'omeunome@omeudominio.pt.'), 0, 'Dominio termina com ponto');
is($v->email('address' => 'omeunome@omeudominio.pt-'), 0, 'Dominio termina com traco');
is($v->email('address' => 'omeunome@.omeudominio.pt'), 0, 'Dominio comeca com ponto');
is($v->email('address' => 'omeunome@-omeudominio.pt'), 0, 'Dominio comeca com traco');
is($v->email('address' => 'omeunome@omeu.-dominio.pt'), 0, 'Dominio com dois caracteres non-word seguidos');
is($v->email('address' => 'omeunome@omeu_dominio.pt'), 0, 'Dominio com _');

